==> packageinstaller-pkglist_0.3.28.tar.xz: packageinstaller-pkglist/German_LO_Latest_full.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>  
German_LO_Latest_full
</name>

<description>  
   <am>German Language Meta-Package for LibreOffice</am>
   <ar>German Language Meta-Package for LibreOffice</ar>
   <bg>German Language Meta-Package for LibreOffice</bg>
   <bn>German Language Meta-Package for LibreOffice</bn>
   <ca>Meta-paquet d'alemany per LibreOffice</ca>
   <cs>German Language Meta-Package for LibreOffice</cs>
   <da>Tysk sprog-metapakke til LibreOffice</da>
   <de>Deutsches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα γερμανικά</el>
   <en>German Language Meta-Package for LibreOffice</en>
   <es>Meta-Paquete de Idioma Alemán para LibreOffice</es>
   <et>German Language Meta-Package for LibreOffice</et>
   <eu>German Language Meta-Package for LibreOffice</eu>
   <fa>German Language Meta-Package for LibreOffice</fa>
   <fil_PH>German Language Meta-Package for LibreOffice</fil_PH>
   <fi>German Language Meta-Package for LibreOffice</fi>
   <fr>Méta-paquet langue allemande pour LibreOffice</fr>
   <he_IL>German Language Meta-Package for LibreOffice</he_IL>
   <hi>German Language Meta-Package for LibreOffice</hi>
   <hr>German Language Meta-Package for LibreOffice</hr>
   <hu>German Language Meta-Package for LibreOffice</hu>
   <id>German Language Meta-Package for LibreOffice</id>
   <is>German Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua tedesca per LibreOffice</it>
   <ja_JP>German Language Meta-Package for LibreOffice</ja_JP>
   <ja>German Language Meta-Package for LibreOffice</ja>
   <kk>German Language Meta-Package for LibreOffice</kk>
   <ko>German Language Meta-Package for LibreOffice</ko>
   <lt>German Language Meta-Package for LibreOffice</lt>
   <mk>German Language Meta-Package for LibreOffice</mk>
   <mr>German Language Meta-Package for LibreOffice</mr>
   <nb>German Language Meta-Package for LibreOffice</nb>
   <nl>Duitse Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Niemiecki metapakiet językowy dla LibreOffice</pl>
   <pt_BR>Alemão Meta-Pacote de Idioma para LibreOffice</pt_BR>
   <pt>Alemão Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>German Language Meta-Package for LibreOffice</ro>
   <ru>German Language Meta-Package for LibreOffice</ru>
   <sk>German Language Meta-Package for LibreOffice</sk>
   <sl>German Language Meta-Package for LibreOffice</sl>
   <sq>German Language Meta-Package for LibreOffice</sq>
   <sr>German Language Meta-Package for LibreOffice</sr>
   <sv>Tyskt Språk Meta-Paket för LibreOffice</sv>
   <tr>German Language Meta-Package for LibreOffice</tr>
   <uk>German Language Meta-Package for LibreOffice</uk>
   <vi>German Language Meta-Package for LibreOffice</vi>
   <zh_CN>German Language Meta-Package for LibreOffice</zh_CN>
   <zh_TW>German Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t buster-backports libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-gtk3
libreoffice-l10n-de
</install_package_names>

<postinstall>
rm /etc/apt/sources.list.d/pitemp.list
apt-get update
</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-gtk3
libreoffice-l10n-de
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/German_LO_Latest_full.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
German_LO_Latest_full
</name>

<description>
   <am>German Language Meta-Package for LibreOffice</am>
   <ar>German Language Meta-Package for LibreOffice</ar>
   <be>German Language Meta-Package for LibreOffice</be>
   <bg>German Language Meta-Package for LibreOffice</bg>
   <bn>German Language Meta-Package for LibreOffice</bn>
   <ca>Meta-paquet d'alemany per LibreOffice</ca>
   <cs>German Language Meta-Package for LibreOffice</cs>
   <da>Tysk sprog-metapakke til LibreOffice</da>
   <de>Deutsches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Γερμανικά</el>
   <en>German Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de Idioma Alemán para LibreOffice</es_ES>
   <es>Metapaquete de Idioma Alemán para LibreOffice</es>
   <et>German Language Meta-Package for LibreOffice</et>
   <eu>German Language Meta-Package for LibreOffice</eu>
   <fa>German Language Meta-Package for LibreOffice</fa>
   <fil_PH>German Language Meta-Package for LibreOffice</fil_PH>
   <fi>Saksankielinen kielipaketti LibreOffice:lle </fi>
   <fr_BE>German Language Meta-Package for LibreOffice</fr_BE>
   <fr>Méta-paquet langue allemande pour LibreOffice</fr>
   <gl_ES>Alemán Meta-paquete de Idioma para LibreOffice</gl_ES>
   <he_IL>German Language Meta-Package for LibreOffice</he_IL>
   <hi>German Language Meta-Package for LibreOffice</hi>
   <hr>German Language Meta-Package for LibreOffice</hr>
   <hu>German Language Meta-Package for LibreOffice</hu>
   <id>German Language Meta-Package for LibreOffice</id>
   <is>German Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua tedesca per LibreOffice</it>
   <ja>LibreOffice用のドイツ語メタパッケージ</ja>
   <kk>German Language Meta-Package for LibreOffice</kk>
   <ko>German Language Meta-Package for LibreOffice</ko>
   <lt>German Language Meta-Package for LibreOffice</lt>
   <mk>German Language Meta-Package for LibreOffice</mk>
   <mr>German Language Meta-Package for LibreOffice</mr>
   <nb_NO>German Language Meta-Package for LibreOffice</nb_NO>
   <nb>Tysk språkpakke for LibreOffice</nb>
   <nl_BE>German Language Meta-Package for LibreOffice</nl_BE>
   <nl>Duitse Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Niemiecki metapakiet językowy dla LibreOffice</pl>
   <pt_BR>Alemão Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Alemão Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>German Language Meta-Package for LibreOffice</ro>
   <ru>German Language Meta-Package for LibreOffice</ru>
   <sk>German Language Meta-Package for LibreOffice</sk>
   <sl>German Language Meta-Package for LibreOffice</sl>
   <sq>German Language Meta-Package for LibreOffice</sq>
   <sr>German Language Meta-Package for LibreOffice</sr>
   <sv>Tyskt Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา German สำหรับ LibreOffice</th>
   <tr>LibreOffice için Almanca Dili Üst-Paketi</tr>
   <uk>German Language Meta-Package for LibreOffice</uk>
   <vi>German Language Meta-Package for LibreOffice</vi>
   <zh_CN>LibreOffice 德语语言包</zh_CN>
   <zh_HK>German Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>German Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t buster-backports libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-gtk3
libreoffice-l10n-de
</install_package_names>

<postinstall>
rm /etc/apt/sources.list.d/pitemp.list
apt-get update
</postinstall>

<uninstall_package_names>
libreoffice-base-core
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-base
libreoffice-gtk3
libreoffice-l10n-de
</uninstall_package_names>

</app>
